@@ -1,8 +1,5 @@
 """Loaders for coercion data."""
-
-# pylint: disable = non-ascii-name,missing-function-docstring
-
-from typing import Optional
+from __future__ import annotations
 
 import pandas as pd
 
@@ -13,11 +10,11 @@ from psycop_feature_generation.utils import data_loaders
 
 @data_loaders.register("coercion_duration")
 def coercion_duration(
-    coercion_type: Optional[str] = None,
-    reason_for_coercion: Optional[str] = None,
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    coercion_type: str | None = None,
+    reason_for_coercion: str | None = None,
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str = "D",
 ) -> pd.DataFrame:
     """Load coercion data. By default returns entire coercion data view with
     duration in hours as the value column.
@@ -63,13 +60,12 @@ def coercion_duration(
     # Drop duplicate rows
     df = df.drop_duplicates(keep="first")
 
-    df.rename(
+    df = df.rename(
         columns={"datotid_slut_sei": "timestamp", "varighed_timer_sei": "value"},
-        inplace=True,
     )
 
     # Change NaNs to 0
-    df["value"].fillna(0, inplace=True)
+    df["value"].fillna(0, inplace=True)  # noqa
 
     if unpack_to_intervals:
         df = unpack_intervals(
@@ -84,16 +80,16 @@ def coercion_duration(
 
 def _concatenate_coercion(
     coercion_types_list: list[dict[str, str]],
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     """Aggregate multiple types of coercion with multiple reasons into one
     column.
 
     Args:
         coercion_types_list (list): list of dictionaries containing a 'coercion_type' key and a 'reason_for_coercion' key. If keys not in dicts, they are set to None # noqa: DAR102
-        n (int, optional): Number of rows to return. Defaults to None.
+        n_rows (int, optional): Number of rows to return. Defaults to None.
         unpack_to_intervals: Unpack time interval to rows with set frequency (see below). Defaults to False.
         unpack_freq:  unpack_freq: Frequency string by which the interval will be unpacked. Default to "D" (day). For e.g., 5 hours, write "5H".
 
@@ -125,14 +121,11 @@ def _concatenate_coercion(
     return pd.concat(dfs, axis=0).reset_index(drop=True)
 
 
-# REASON (begrundtekst_sei) #
-
-
 @data_loaders.register("farlighed")
 def farlighed(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     coercion_types_list = [
         {
@@ -154,9 +147,9 @@ def farlighed(
 # Røde papirer ved tvangsindlæggelse/tvangstilbageholdelse
 @data_loaders.register("paa_grund_af_farlighed")
 def paa_grund_af_farlighed(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         reason_for_coercion="På grund af farlighed",
@@ -169,9 +162,9 @@ def paa_grund_af_farlighed(
 # Gule papirer ved tvangsindlæggelse/tvangstilbageholdelse
 @data_loaders.register("af_helbredsmaessige_grunde")
 def af_helbredsmaessige_grunde(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         reason_for_coercion="Af helbredsmæssige grunde",
@@ -183,9 +176,9 @@ def af_helbredsmaessige_grunde(
 
 @data_loaders.register("urolig_tilstand")
 def urolig_tilstand(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         reason_for_coercion="Urolig tilstand",
@@ -197,9 +190,9 @@ def urolig_tilstand(
 
 @data_loaders.register("anden_begrundelse")
 def anden_begrundelse(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         reason_for_coercion="Anden begrundelse",
@@ -211,9 +204,9 @@ def anden_begrundelse(
 
 @data_loaders.register("naerliggende_eller_vaesentlig_fare_for_patienten_eller_andre")
 def naerliggende_fare(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         reason_for_coercion="Nærliggende_eller_væsentlig_fare_for_patienten_eller_andre",
@@ -227,9 +220,9 @@ def naerliggende_fare(
 # frihedsberøvelser
 @data_loaders.register("skema_1")
 def skema_1(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     coercion_types_list = [
         {
@@ -251,9 +244,9 @@ def skema_1(
 # tvangsbehandlinger
 @data_loaders.register("skema_2")
 def skema_2(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     coercion_types_list = [
         {
@@ -280,9 +273,7 @@ def skema_2(
 
 @data_loaders.register("skema_2_without_nutrition")
 def skema_2_without_nutrition(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
 ) -> pd.DataFrame:
     coercion_types_list = [
         {
@@ -305,9 +296,9 @@ def skema_2_without_nutrition(
 # magtanvendelse
 @data_loaders.register("skema_3")
 def skema_3(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     coercion_types_list = [
         {
@@ -343,9 +334,9 @@ def skema_3(
 
 @data_loaders.register("baelte")
 def baelte(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         coercion_type="Bælte",
@@ -357,9 +348,9 @@ def baelte(
 
 @data_loaders.register("remme")
 def remme(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         coercion_type="Remme",
@@ -371,9 +362,9 @@ def remme(
 
 @data_loaders.register("fastholden")
 def fastholden(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         coercion_type="Fastholden",
@@ -385,9 +376,9 @@ def fastholden(
 
 @data_loaders.register("beroligende_medicin")
 def beroligende_medicin(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         coercion_type="Beroligende medicin",
@@ -399,9 +390,9 @@ def beroligende_medicin(
 
 @data_loaders.register("handsker")
 def handsker(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         coercion_type="Handsker",
@@ -413,9 +404,9 @@ def handsker(
 
 @data_loaders.register("tvangsindlaeggelse")
 def tvangsindlaeggelse(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         coercion_type="Tvangsindlæggelse",
@@ -427,9 +418,9 @@ def tvangsindlaeggelse(
 
 @data_loaders.register("tvangstilbageholdelse")
 def tvangstilbageholdelse(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         coercion_type="Tvangstilbageholdelse",
@@ -441,9 +432,9 @@ def tvangstilbageholdelse(
 
 @data_loaders.register("medicinering")
 def medicinering(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         coercion_type="Medicinering",
@@ -455,9 +446,9 @@ def medicinering(
 
 @data_loaders.register("ect")
 def ect(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         coercion_type="ECT",
@@ -469,9 +460,9 @@ def ect(
 
 @data_loaders.register("ernaering")
 def ernaering(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         coercion_type="Ernæring",
@@ -483,9 +474,9 @@ def ernaering(
 
 @data_loaders.register("af_legemlig_lidelse")
 def af_legemlig_lidelse(
-    n_rows: Optional[int] = None,
-    unpack_to_intervals: Optional[bool] = False,
-    unpack_freq: Optional[str] = "D",
+    n_rows: int | None = None,
+    unpack_to_intervals: bool | None = False,
+    unpack_freq: str | None = "D",
 ) -> pd.DataFrame:
     return coercion_duration(
         coercion_type="Af legemlig lidelse",
